pro trace_cat, t0, t1, catalog, debug=debug, fast=fast, loud=loud, $
       count=count, status=status, deltat=deltat, short=short, _extra=_extra,$
       engineering=engineering, $
       cosmic=cosmic, prefix=prefix, wave=wave, qrev=qrev, $
       initialize=initialize
;+
;   Name: trace_cat
;
;   Purpose: read TRACE catalog (via setup/call to 'read_genxcat')  
;
;   Input Parameters:
;      t0, t1 - timerange for read
;
;   Keyword Parameters:
;      short - if set, read/return catalog 'short form'
;      status - success, 1=>1 or more records between t0 and t1 found
;                        0=>no records between t0 and t1
;      deltat - if no records between t0 and t1, deltaT of closest match
;      count  - number of catalog entries returned
;      engineering - if set, read engineering catalog
;      cosmic - if set, read cosmic ray dbase
;      prefix - optional prefix to use
;
;   Output:
;      catalog - catalog entries (idl strutures) between t0 and t1  
;
;   Callling Sequence:
;        trace_cat, t0 , t1, catalog [,/short] [,/engineering]
;   -OR- trace_cat, catalog , /LASTXX (last XX hours)
;   History:
;      16-April-1998 - S.L.Freeland - provide TRACE front end to read_genxcat
;      18-April-1998 - S.L.Freeland - add /LASTXX option
;      25-June-1998  - S.L.Freeland - add STATUS and DELTAT (out from read_genx)
;      29-June-1999  - S.L.Freeland - add /COSMIC keyword and function
;      15-July-1999  - S.L.Freeland - add /QREV (use /cosmic and wave='xx' to get "opposite" quadrant...)
;      12-May-2001   - Zarro (EITI/GSFC) - added TRACE_I1_DIR search dir 
;-  
common trace_cat_blk, init

initialize=keyword_set(initialize) or n_elements(init) eq 0
init=1

tdb=get_logenv('tdb')

if n_params() eq 0 then begin
   box_message,['     IDL> trace_cat, t0, t1, catalog [,/short]' , $ 
                '-OR- IDL> trace_cat, catalog , /LASTXX        ;last XX hours']
   return
endif

if tdb(0) eq '' then tdb=concat_dir('SSWDB','tdb')
if not file_exist(tdb) then tdb='/DataCenter/trace/tdb'
if not file_exist(tdb) then tdb=concat_dir('TRACE_I1_DIR','tdb')
if not file_exist(tdb) then begin
   box_message,'Cannot find $tdb or $SSWDB/tdb'
   return
endif

cosmic=keyword_set(cosmic)
if n_elements(wave) eq 0 then wave='' else $
    wave='_'+strtrim(wave,2)

case 1 of
  keyword_set(short): catdir=concat_dir(tdb,'tcs')
  keyword_set(engineering): catdir=concat_dir(tdb,'tce')
  cosmic: begin
     catdir=concat_dir(tdb,'tcc' + wave)
     if keyword_set(qrev) then catdir=catdir+'_qrev'
  endcase
  else: catdir=concat_dir(tdb,'tcl')
endcase


; allow /lastxxx where xxx=hours
option=0
if data_chk(_extra,/struct) then begin
   tags=tag_names(_extra)
   hours=(where( strpos(tags,'LAST') ne -1 ,hcnt))(0)
   if hcnt gt 0 then begin
      hours=strmid(tags(hours),4,3)   
      if not is_number(hours) then hours=24
      t1=ut_time()
      t0=timegrid(t1,hour=-(hours),/string)
      box_message,'/LAST set, Using times: ' + t0 + ' - ' + t1
      option=1
    endif
endif

read_genxcat,t0, t1, catalog, loud=loud, debug=debug, $
    count=count, status=status, deltat=deltat, topdir=catdir, $
    initialize=initialize

if option and n_elements(catalog) gt 0 then t0=temporary(catalog)
 
return
end
